@@ -1,11 +1,3 @@
-# vertex.attrs <- function(x)
-# edge.attrs <- function(x)
-#
-# `[<-.diffnet` <- function(graph, v, value) {
-#   graph$vertex.attrs[v] <- value
-#   graph
-# }
-
 #' @export
 #' @rdname as_diffnet
 plot.diffnet <- function(
@@ -14,6 +6,9 @@ plot.diffnet <- function(
   vertex.cex = "degree", edge.col = "gray", mode = "fruchtermanreingold",
   layout.par = NULL, main = "Diffusion network in time %d", ...) {
 
+  # Listing arguments
+  args <- list(...)
+
   # Checking that the time period is actually within
   if (!(t %in% 1:x$meta$nper))
     stop("-t- must be an integer within 1 and ",x$meta$nper,".")
@@ -25,8 +20,14 @@ plot.diffnet <- function(
   cols <- with(x, ifelse(cumadopt[,t], vertex.col[1], vertex.col[2]))
 
   # Calcularing layout
-  fun <- getFromNamespace(paste0("gplot.layout.",mode), "sna")
-  coords <- fun(graph, layout.par)
+
+   if ("coord" %in% names(args)) {
+     coords <- args[["coord"]]
+     args[["coord"]] <- NULL
+   } else {
+     fun <- getFromNamespace(paste0("gplot.layout.",mode), "sna")
+     coords <- fun(graph, layout.par)
+   }
 
   # Computing sizes
   if ((length(vertex.cex) == 1) && inherits(vertex.cex, "character"))
@@ -41,9 +42,10 @@ plot.diffnet <- function(
       stop("Invalid -vertex.cex-")
     }
 
-  sna::gplot(graph, displaylabels=displaylabels, vertex.col=cols,
+  do.call(sna::gplot, c(list(dat=graph, displaylabels=displaylabels, vertex.col=cols,
              coord=coords, edge.col=edge.col, label=x$meta$ids,
-             main=sprintf(main, x$meta$pers[t]), vertex.cex=vertex.cex, gmode=gmode, ...)
+             main=sprintf(main, x$meta$pers[t]), vertex.cex=vertex.cex, gmode=gmode),
+             args))
 
   invisible(coords)
 }
@@ -197,10 +199,10 @@ summary.diffnet <- function(object, slices=NULL, no.print=FALSE,
 #'
 #' @param graph A dynamic graph (see \code{\link{netdiffuseR-graphs}}).
 #' @param cumadopt \eqn{n\times T}{n*T} matrix.
-#' @param displaylabels Logical scalar. When TRUE vertex labels are displayed (see \code{\link[sna:gplot]{gplot}})
 #' @param slices Integer vector. Indicates what slices to plot. By default all are plotted.
 #' @param undirected Logical scalar.
 #' @param vertex.col A character vector of size 3 with colors names.
+#' @param vertex.shape A character vector of size 3 with shape names.
 #' @param vertex.cex Numeric vector of size \eqn{n}. Size of the vertices.
 #' @param label Character vector of size \eqn{n}. If no provided, rownames of
 #' the graph are used.
@@ -209,10 +211,13 @@ summary.diffnet <- function(object, slices=NULL, no.print=FALSE,
 #' @param layout.par Layout parameters (see details).
 #' @param mfrow.par Vector of size 2 with number of rows and columns to be passed to \code{\link{par}.}
 #' @param main Character scalar. A title template to be passed to \code{\link{sprintf}.}
-#' @param mai Numeric vector of size 4. To be passed to \code{\link{par}.}
-#' @param mar Numeric vector of size 4. To be passed to \code{\link{par}.}
 #' @param gmode Character scalar. See \code{\link[sna:gplot]{gplot}.}
-#' @param ... Further arguments to be passed to \code{\link[sna:gplot]{gplot}.}
+#' @param vertex.frame.color Passed to \code{\link[igraph:plot.igraph]{plot.igraph}}
+#' @param edge.arrow.size Passed to \code{\link[igraph:plot.igraph]{plot.igraph}}
+#' @param intra.space Passed to \code{\link[igraph:plot.igraph]{plot.igraph}}
+#' @param key.height Numeric scalar. Sets the proportion of the plot (y-axis) that the key uses.
+#' @param rescale.fun A function to rescale vertex size. By defult it is set to be \code{\link{rescale_vertex_igraph}}
+#' @param ... Further arguments to be passed to \code{\link[igraph:plot.igraph]{plot.igraph}}.
 #' @param coords Numeric matrix of size \eqn{n\times 2}{n * 2} with vertices coordinates.
 #' @param lgd List of arguments to be passed to \code{\link{legend}}.
 #'
@@ -262,30 +267,38 @@ summary.diffnet <- function(object, slices=NULL, no.print=FALSE,
 plot_diffnet <- function(
   graph, cumadopt,
   slices=NULL,
-  displaylabels=FALSE,
   undirected=TRUE,
-  vertex.col=c("grey", "red", "blue"),
+  vertex.col=c("white", "red", "blue"),
+  vertex.shape=c("square", "circle", "circle"),
   vertex.cex="degree",
-  label=rownames(graph[[1]]),
+  label=NA,
   edge.col="gray",
   mode="fruchtermanreingold", layout.par=NULL,
   mfrow.par=NULL, main="Network in period %d",
-  mai=c(0,0,1,0),
-  mar=rep(1,4) + 0.1, gmode=ifelse(undirected, "graph", "digraph"),
-  lgd = list(x="center", legend=c("Non adopters", "New adopters","Adopters"), pch=21,
-             bty="n", cex=1.2, horiz=TRUE), coords=NULL,...
+  gmode=ifelse(undirected, "graph", "digraph"),
+  lgd = list(x="bottom", legend=c("Non-adopters", "New adopters","Adopters"), pch=21,
+             bty="n", cex=1.2, horiz=TRUE), coords=NULL,
+  vertex.frame.color="gray",
+  edge.arrow.size=.25,
+  intra.space=c(.15,.15),
+  key.height = 0.1,
+  rescale.fun = function(x) rescale_vertex_igraph(x, adjust = 100),
+  ...
 ) {
   switch (class(graph),
     array = plot_diffnet.array(
-      graph, cumadopt, slices, displaylabels, undirected, vertex.col, vertex.cex, label,
-      edge.col, mode, layout.par, mfrow.par, main, mai, mar, gmode, lgd, coords,...),
+      graph, cumadopt, slices, undirected, vertex.col, vertex.shape, vertex.cex, label,
+      edge.col, mode, layout.par, mfrow.par, main, gmode, lgd, coords,
+      vertex.frame.color, edge.arrow.size, intra.space, key.height, rescale.fun,...),
     list = plot_diffnet.list(
-      graph, cumadopt, slices, displaylabels, undirected, vertex.col, vertex.cex, label,
-      edge.col, mode, layout.par, mfrow.par, main, mai, mar, gmode, lgd, coords,...),
+      graph, cumadopt, slices, undirected, vertex.col, vertex.shape, vertex.cex, label,
+      edge.col, mode, layout.par, mfrow.par, main, gmode, lgd, coords,
+      vertex.frame.color, edge.arrow.size, intra.space, key.height, rescale.fun,...),
     diffnet = plot_diffnet.list(
-      graph$graph, graph$cumadopt, slices, displaylabels, graph$meta$undirected,
-      vertex.col, vertex.cex, label=graph$meta$ids,
-      edge.col, mode, layout.par, mfrow.par, main, mai, mar, gmode, lgd, coords,...),
+      graph$graph, graph$cumadopt, slices, graph$meta$undirected,
+      vertex.col, vertex.shape, vertex.cex, label,
+      edge.col, mode, layout.par, mfrow.par, main, gmode, lgd, coords,
+      vertex.frame.color, edge.arrow.size, intra.space, key.height, rescale.fun,...),
     stopifnot_graph(graph)
   )
 }
@@ -293,29 +306,31 @@ plot_diffnet <- function(
 # @export
 # @rdname plot_diffnet
 plot_diffnet.array <- function(graph, ...) {
-  dn <- dimnames(graph)[[3]]
-  graph <- lapply(1:dim(graph)[3], function(x) graph[,,x])
-  names(graph) <- dn
+  graph <- apply(graph, 3, methods::as, Class="dgCMatrix")
   plot_diffnet.list(graph, ...)
 }
 
 # @export
 # @rdname plot_diffnet
 plot_diffnet.list <- function(graph, cumadopt, slices,
-                         displaylabels=FALSE,
                          undirected=TRUE,
-                         vertex.col=c("grey", "red", "blue"),
+                         vertex.col=c("white", "red", "blue"),
+                         vertex.shape=c("square", "circle", "circle"),
                          vertex.cex="degree",
-                         label=rownames(graph[[1]]),
+                         label=NA,
                          edge.col="gray",
                          mode="fruchtermanreingold", layout.par=NULL,
                          mfrow.par=NULL, main="Network in period %d",
-                         mai=c(0,0,1,0),
-                         mar=rep(1,4) + 0.1,
                          gmode=ifelse(undirected, "graph", "digraph"),
-                         lgd = list(x="center", legend=c("Non adopters", "New adopters","Adopters"), pch=21,
+                         lgd = list(x="bottom", legend=c("Non adopters", "New adopters","Adopters"), pch=21,
                                     bty="n", cex=1.2, horiz=TRUE),
-                         coords=NULL, ...) {
+                         coords=NULL,
+                         vertex.frame.color="gray",
+                         edge.arrow.size=.25,
+                         intra.space=c(.15,.15),
+                         key.height = 0.1,
+                         rescale.fun = function(x) rescale_vertex_igraph(x, adjust = 100),
+                         ...) {
 
   # Checking slices
   if (!length(slices)) slices <- 1:ncol(cumadopt)
@@ -340,16 +355,10 @@ plot_diffnet.list <- function(graph, cumadopt, slices,
   if ((length(vertex.cex) == 1) && inherits(vertex.cex, "character"))
     if (vertex.cex %in% c("degree", "indegree", "outdegree")) {
       vertex.cex <- dgr(cumgraph, cmode = vertex.cex, undirected=undirected)
-      vertex.cex <- sqrt(vertex.cex)
-      r <- range(vertex.cex)
-      vertex.cex <- (vertex.cex - r[1]+ .1)/(r[2] - r[1] + .1)*2
     } else {
       stop("Invalid -vertex.cex-")
     }
 
-#   if ( (length(vertex.cex)==1) && (n > 1) )
-#     vertex.cex <- rep(vertex.cex,n)
-
   # Figuring out the dimension
   if (!length(mfrow.par)) {
     if (t<4) mfrow.par <- c(1,t)
@@ -365,53 +374,86 @@ plot_diffnet.list <- function(graph, cumadopt, slices,
     else mfrow.par <- c(ceiling(t/4),4)
   }
 
-  test <- prod(mfrow.par)-t
-  if (test) {
-    marlayout <- matrix(1:prod(mfrow.par), ncol=mfrow.par[2], byrow = TRUE)
-    marlayout[nrow(marlayout),(ncol(marlayout) - test + 1):ncol(marlayout)] <- t + 1
-    lgd$horiz <- FALSE
-  } else {
-    marlayout <- rbind(matrix(1:prod(mfrow.par), ncol=mfrow.par[2], byrow = TRUE),
-                       prod(mfrow.par)+1)
-  }
 
-  # Plotting
-  # curseed <- .Random.seed
-  oldpar <- par(no.readonly = TRUE)
-  # par(mfrow=mfrow.par, mai=mai, mar=mar)
-  par(mai=mai, mar=mar)
-  layout(marlayout)
+  # 1. Computing dims ----------------------------------------------------------
+  intra.space <- intra.space + 1
+  xrange <- range(coords[,1])
+  xlim   <- xrange + c(0, (xrange[2]-xrange[1])*intra.space[1]*(mfrow.par[2] - 1))
 
+  yrange <- range(coords[,1])
+  ylim   <- yrange - c((yrange[2]-yrange[1])*intra.space[2]*(mfrow.par[1] - 1), 0)
+
+  # Adjustems depending on the number of slice
+  irow <- t(matrix(0:(mfrow.par[1]-1), nrow=mfrow.par[1], ncol=mfrow.par[2], byrow = FALSE))
+  icol <- t(matrix(0:(mfrow.par[2]-1), nrow=mfrow.par[1], ncol=mfrow.par[2], byrow = TRUE))
+
+  # 2. Set up frame
+  plot.new()
+  ylim <- grDevices::extendrange(ylim, ylim)
+  plot.window(
+    grDevices::extendrange(xlim),
+    ylim - c((ylim[2]-ylim[1])*key.height, 0))
+
+  # 3. Plotting
   times <- as.integer(names(graph))
-  for(i in 1:t)  {
+  for (i in 1:t) {
     # Colors, new adopters are painted differently
     cols <- ifelse(!cumadopt[,i], vertex.col[1],
-                   ifelse(!cumadopt[,i-1*(i!=1)] | rep(i,n) == 1, vertex.col[2], vertex.col[3]))
+                   ifelse(!cumadopt[,i-(i!=1)] | rep(i,n) == 1, vertex.col[2], vertex.col[3]))
 
-    # set.seed(curseed)
-    # cgraph <- sna::as.sociomatrix.sna(adjmat_to_edgelist(graph[[i]], undirected))
-    if (inherits(graph[[i]], "dgCMatrix")) g <- methods::as(graph[[i]], "matrix.csc")
+    # Shapes
+    shapes <- ifelse(!cumadopt[,i], vertex.shape[1],
+                     ifelse(!cumadopt[,i-(i!=1)] | rep(i,n) == 1, vertex.shape[2], vertex.shape[3]))
+
+    # Computing coords
+    coords_adjs <- cbind(
+      coords[,1] + icol[i]*intra.space[1]*(xrange[2]-xrange[1]),
+      coords[,2] - irow[i]*intra.space[2]*(yrange[2]-yrange[1]))
+
+    # Title
+    if (length(main)) {
+      # Creating the title and computing how much space should be
+      itit <- sprintf(main, slices[i])
+      nlines <- length(strsplit(main, "\n")[[1]])
+      tspace <- par("cxy")[2]*(nlines + .5)
+
+      # Adjusting coords
+      ystart <- range(coords_adjs[,2])
+      coords_adjs[,2] <- (coords_adjs[,2] - ystart[1])/(ystart[2] - ystart[1])*(
+        ystart[2] - ystart[1] - tspace) + ystart[1]
+
+      # Including text
+      xstart <- range(coords_adjs[,1])
+      text(
+        x = (xstart[2] + xstart[1])/2,
+        y = ystart[2] - tspace,
+        labels = itit,
+        pos=3
+      )
+
+    }
+
+    # Coercing into the right method
+    if (!inherits(graph[[i]], "dgCMatrix")) g <- methods::as(graph[[i]], "dgCMatrix")
     else g <- graph[[i]]
-    sna::gplot(g,
-               displaylabels = displaylabels, vertex.col = cols, coord=coords,
-               edge.col = edge.col,vertex.cex = vertex.cex, label=label,
-               main=sprintf(main, times[i]), gmode=gmode, ...)
+
+    # Plotting
+    igraph::plot.igraph(igraph::graph_from_adjacency_matrix(g),
+                        vertex.color = cols,
+                        layout = coords_adjs,
+                        edge.color = edge.col,
+                        vertex.size = rescale.fun(vertex.cex),
+                        vertex.label=label,
+                        add=TRUE, rescale=FALSE,
+                        edge.arrow.size=edge.arrow.size,
+                        vertex.frame.color = vertex.frame.color,
+                        vertex.shape=shapes,
+                        ...)
   }
 
   # Legend
-  plot.new()
-  plot.window(xlim=c(0,1), ylim=c(0,1))
+  do.call(legend, c(lgd, list(pt.bg=vertex.col)))
 
-  lgd$pt.bg  <- vertex.col
-
-  do.call(legend, lgd)
-
-#   with(lgd,
-#     legend(pos, pt.bg = vertex.col,
-#            legend = text, pch=pch, bty=bty, cex=cex, horiz = horiz)
-#   )
-
-  par(oldpar)
   invisible(coords)
 
 }
@@ -551,9 +593,7 @@ plot_threshold <- function(
 # @export
 # @rdname plot_threshold
 plot_threshold.array <- function(graph, ...) {
-  dn <- dimnames(graph)[[3]]
-  graph <- lapply(1:dim(graph)[3], function(x) graph[,,x])
-  names(graph) <- dn
+  graph <- apply(graph, 3, methods::as, Class="dgCMatrix")
   plot_threshold.list(graph, ...)
 }
 
@@ -573,6 +613,7 @@ plot_threshold.list <- function(
   t <- length(graph)
   n <- nrow(graph[[1]])
 
+
   # Step 1: Creating the cumulative graph
   # Matrix::sparseMatrix(i={}, j={}, dims=c(n, n))
   cumgraph <- methods::new("dgCMatrix", Dim=c(n,n), p=rep(0L, n+1L))
@@ -711,6 +752,7 @@ plot_threshold.list <- function(
 #' @param expdiscount Logical scalar.  Passed to infection/susceptibility.
 #' @param bins Integer scalar. Size of the grid (\eqn{n}).
 #' @param nlevels Integer scalar. Number of levels to plot (see \code{\link{filled.contour}}).
+#' @param h Numeric vector of length 2. Passed to \code{\link[MASS:kde2d]{kde2d}} in the \pkg{MASS} package.
 #' @param logscale Logical scalar. When TRUE the axis of the plot will be presented in log-scale.
 #' @param main Character scalar. Title of the graph.
 #' @param xlab Character scalar. Title of the x-axis.
@@ -726,6 +768,10 @@ plot_threshold.list <- function(
 #'
 #' This plotting function was inspired by Aral, S., & Walker, D. (2012).
 #'
+#' By default the function will try to apply a kernel smooth function via
+#' \code{kde2d}. If not possible (because not enought data points), then
+#' the user should try changing the parameter \code{h} or set it equal to zero.
+#'
 #' @return A list with three elements:
 #' \item{infect}{A numeric vector of size \eqn{n} with infectiousness levels}
 #' \item{suscep}{A numeric vector of size \eqn{n} with susceptibility levels}
@@ -754,10 +800,11 @@ plot_threshold.list <- function(
 #' out <- plot_infectsuscep(graph, toa, K=3, logscale = FALSE)
 #' @author George G. Vega Yon
 plot_infectsuscep <- function(
-  graph, toa, t0=NULL,normalize=TRUE, K=1L, r=0.5, expdiscount=FALSE, bins=20,nlevels=round(bins/2),
+  graph, toa, t0=NULL,normalize=TRUE, K=1L, r=0.5, expdiscount=FALSE, bins=20,nlevels=round(bins/2), h=NULL,
   logscale=TRUE, main="Distribution of Infectiousness and\nSusceptibility",
   xlab="Infectiousness of ego", ylab="Susceptibility of ego",
-  sub=ifelse(logscale, "(in log-scale)", NA), color.palette=function(n) grey(n:1/n),
+  sub=ifelse(logscale, "(in log-scale)", NA),
+  color.palette = grDevices::colorRampPalette(grDevices::blues9),
   include.grid=TRUE, exclude.zeros=FALSE, valued=getOption("diffnet.valued",FALSE), ...
 ) {
 
@@ -774,13 +821,13 @@ plot_infectsuscep <- function(
 
   switch (class(graph),
     array = plot_infectsuscep.array(
-      graph, toa, t0, normalize, K, r, expdiscount, bins, nlevels, logscale, main,
+      graph, toa, t0, normalize, K, r, expdiscount, bins, nlevels, h, logscale, main,
       xlab, ylab, sub, color.palette, include.grid, exclude.zeros, valued, ...),
     list = plot_infectsuscep.list(
-      graph, toa, t0, normalize, K, r, expdiscount, bins, nlevels, logscale, main,
+      graph, toa, t0, normalize, K, r, expdiscount, bins, nlevels, h, logscale, main,
       xlab, ylab, sub, color.palette, include.grid, exclude.zeros, valued,...),
     diffnet = plot_infectsuscep.list(
-      graph$graph, graph$toa, t0, normalize, K, r, expdiscount, bins, nlevels, logscale, main,
+      graph$graph, graph$toa, t0, normalize, K, r, expdiscount, bins, nlevels, h, logscale, main,
       xlab, ylab, sub, color.palette, include.grid, exclude.zeros, valued,...),
     stopifnot_graph(graph)
   )
@@ -789,9 +836,7 @@ plot_infectsuscep <- function(
 # @export
 # @rdname plot_infectsuscep
 plot_infectsuscep.array <- function(graph, ...) {
-  dn <- dimnames(graph)[[3]]
-  graph <- lapply(1:dim(graph)[3], function(x) methods::as(graph[,,x], "dgCMatrix"))
-  names(graph) <- dn
+  graph <- apply(graph, 3, methods::as, Class="dgCMatrix")
   plot_infectsuscep.list(graph, ...)
 }
 
@@ -800,6 +845,7 @@ plot_infectsuscep.array <- function(graph, ...) {
 plot_infectsuscep.list <- function(graph, toa, t0, normalize,
                               K, r, expdiscount,
                               bins,nlevels,
+                              h,
                               logscale,
                               main,
                               xlab,
@@ -811,6 +857,7 @@ plot_infectsuscep.list <- function(graph, toa, t0, normalize,
   # Computing infect and suscept
   infect <- infection(graph, toa, t0, normalize, K, r, expdiscount, valued)
   suscep <- susceptibility(graph, toa, t0, normalize, K, r, expdiscount, valued)
+  complete <- complete.cases(infect, suscep)
 
   # Performing classification (linear)
   if (logscale) {
@@ -818,36 +865,53 @@ plot_infectsuscep.list <- function(graph, toa, t0, normalize,
     suscepp<-log(suscep)
 
     # Only keeping complete cases
-    complete <- is.finite(infectp) & is.finite(suscepp)
+    complete <- complete & is.finite(infectp) & is.finite(suscepp)
+
     if (any(!complete)) warning("When applying logscale some observations are missing.")
-    infectp <- infectp[complete,]
-    suscepp <- suscepp[complete,]
   }
   else {
     infectp <- infect
     suscepp <- suscep
-    complete <- vector(length=length(infectp))
   }
 
+  infectp <- infectp[complete,]
+  suscepp <- suscepp[complete,]
+
   if ((!length(infectp) | !length(suscepp)) & logscale)
     stop("Can't apply logscale (undefined values).")
 
   # If excluding zeros
-  include <- rep(TRUE,length(toa))
+  include <- rep(TRUE,length(infectp))
   if (exclude.zeros) {
     include[!infectp | !suscepp] <- FALSE
   }
 
-  # Computing infect & suscept
-  coords <- netdiffuseR::grid_distribution(x=infectp[include], y=suscepp[include], bins)
 
+  # Computing infect & suscept
+  if (length(h) && h==0) {
+    coords <- grid_distribution(infectp[include], suscepp[include], bins)
+  } else {
+    if (!length(h)) h <- c(
+      MASS::bandwidth.nrd(infectp[include & infectp!=0]),
+      MASS::bandwidth.nrd(suscepp[include & suscepp!=0])
+      )
+
+    # Cant use smoother
+    if (any((h==0) | is.na(h)))
+      stop('Not enought data to perform smooth. Try choosing another value for -h-,',
+           ' or set h=0 (no kernel smooth).')
+    coords <- MASS::kde2d(infectp[include], suscepp[include], n = bins, h = h)
+  }
 
   # Nice plot
+
+
+
   n <- sum(coords$z)
   with(coords, filled.contour(
     x,y,
     z/n, bty="n", main=main, xlab=xlab, ylab=ylab, sub=sub, color.palette =color.palette,
-    xlim=range(pretty(x)), ylim=range(pretty(y)),
+    xlim=range(x), ylim=range(y),
     plot.axes={
 
       # Preparing the tickmarks for the axis
@@ -870,6 +934,11 @@ plot_infectsuscep.list <- function(graph, toa, t0, normalize,
     }, nlevels=nlevels, ...))
   # if (include.grid) grid()
 
+  # Adding some reference
+  legend("topleft", legend=
+         sprintf('\n%d out of %d obs.\nincluded', sum(include), length(complete)),
+         bty="n")
+
   invisible(list(infect=infect, suscept=suscep, coords=coords,
                  complete=complete))
 }
@@ -981,9 +1050,10 @@ plot_adopters <- function(obj, freq=FALSE, what=c("adopt","cumadopt"),
 # x["num",]
 
 
-#' \code{diffnet} Arithmetic Operators
+#' \code{diffnet} Arithmetic and Logical Operators
 #'
-#' Addition, substraction and network power of diffnet objects
+#' Addition, substraction, network power of diffnet and logical operators such as
+#' \code{&} and \code{|} as objects
 #'
 #' @param x A \code{diffnet} class object.
 #' @param y Integer scalar. Power of the network
@@ -1049,8 +1119,6 @@ graph_power <- function(x, y, valued=getOption("diffnet.valued", FALSE)) {
 
 #' @rdname diffnet-arithmetic
 #' @export
-#' @param e1 A diffnet object.
-#' @param e2 Either a diffnet object, an integer vector or a character vector.
 #' @examples
 #' # Removing the first 3 vertex of medInnovationsDiffnet ----------------------
 #' data(medInnovationsDiffNet)
@@ -1064,36 +1132,134 @@ graph_power <- function(x, y, valued=getOption("diffnet.valued", FALSE)) {
 #'
 #' # Using ids
 #' medInnovationsDiffNet - as.character(1001:1003)
-`-.diffnet` <- function(e1, e2) {
-  if (inherits(e1, "diffnet") & inherits(e2, "diffnet")) {
+`-.diffnet` <- function(x, y) {
+  if (inherits(x, "diffnet") & inherits(y, "diffnet")) {
 
     # Listing the id numbers that wont be removed
-    ids.to.remove <- e2$meta$ids
-    ids.to.remove <- which(e1$meta$ids %in% ids.to.remove)
-    e1[-ids.to.remove, , drop=FALSE]
-  } else if (inherits(e1, "diffnet") & any(class(e2) %in% c("integer", "numeric"))) {
+    ids.to.remove <- y$meta$ids
+    ids.to.remove <- which(x$meta$ids %in% ids.to.remove)
+    x[-ids.to.remove, , drop=FALSE]
+  } else if (inherits(x, "diffnet") & any(class(y) %in% c("integer", "numeric"))) {
 
     # Dropping using ids
-    e1[-e2,, drop=FALSE]
-  } else if (inherits(e1, "diffnet") & inherits(e2, "character")) {
+    x[-y,, drop=FALSE]
+  } else if (inherits(x, "diffnet") & inherits(y, "character")) {
     # Checking labels exists
-    test <- which(!(e2 %in% e1$meta$ids))
+    test <- which(!(y %in% x$meta$ids))
     if (length(test))
-      stop("Some elements in -e2- (right hand size of the expression) are not ",
+      stop("Some elements in -y- (right hand size of the expression) are not ",
            "in the set of ids of the diffnet object:\n\t",
-           paste0(e2[test], collapse=", "),".")
+           paste0(y[test], collapse=", "),".")
 
-    e2 <- which(e1$meta$ids %in% e2)
-    e1[-e2,,drop=FALSE]
+    y <- which(x$meta$ids %in% y)
+    x[-y,,drop=FALSE]
   } else
-    stop("Substraction between -",class(e1),"- and -", class(e2), "- not supported.")
+    stop("Substraction between -",class(x),"- and -", class(y), "- not supported.")
 }
 
-# #' @export
-# #' @rdname as_diffnet
-# subset.diffnet <- function(x, subset, ...) {
-#
-# }
+#' @export
+#' @rdname diffnet-arithmetic
+`*.diffnet` <- function(x,y) {
+  if (inherits(x, "diffnet") & inherits(y, "diffnet")) {
+
+    # Checking dimmensions
+    test <- all(dim(x) == dim(y))
+    if (!test)
+      stop('Both -x- and -y- must have the same dimmensions.')
+
+    x$graph <- mapply(`*`, x$graph, y$graph)
+    return(x)
+  } else if (inherits(x, "diffnet") & is.numeric(y)) {
+    x$graph <- mapply(`+`, x$graph, y)
+    return(x)
+
+  } else
+    stop("Multiplication between -",class(x),"- and -", class(y), "- not supported.")
+}
+
+#' @export
+#' @rdname diffnet-arithmetic
+`&.diffnet` <- function(x,y) {
+  x$graph <- mapply(function(a,b) methods::as(a & b, "dgCMatrix"), x$graph, y$graph)
+  x
+}
+
+#' @export
+#' @rdname diffnet-arithmetic
+`|.diffnet` <- function(x,y) {
+  x$graph <- mapply(function(a,b) methods::as(a | b, "dgCMatrix"), x$graph, y$graph)
+  x
+}
+
+#' Matrix multiplication
+#'
+#' Matrix multiplication methods, including \code{\link{diffnet}}
+#' objects. This function creates a generic method for \code{\link[base:matmult]{\%*\%}}
+#' allowing for multiplying diffnet objects.
+#'
+#' @param x Numeric or complex matrices or vectors, or \code{diffnet} objects.
+#' @param y Numeric or complex matrices or vectors, or \code{diffnet} objects.
+#'
+#' @details This function can be usefult to generate alternative graphs, for
+#' example, users could compute the n-steps graph by doing \code{net \%*\% net}
+#' (see examples).
+#'
+#' @return In the case of \code{diffnet} objects performs matrix multiplication
+#' via \code{\link{mapply}} using \code{x$graph} and \code{y$graph} as arguments,
+#' returnling a \code{diffnet}. Otherwise returns the default according to
+#' \code{\link[base:matmult]{\%*\%}}.
+#'
+#' @examples
+#' # Finding the Simmelian Ties network ----------------------------------------
+#'
+#' # Random diffnet graph
+#' set.seed(773)
+#' net <- rdiffnet(100, 4, seed.graph='small-world', rgraph.args=list(k=8))
+#' netsim <- net
+#'
+#' # According to Dekker (2006), Simmelian ties can be computed as follows
+#' netsim <- net * t(net) # Keeping mutal
+#' netsim <- netsim * (netsim %*% netsim)
+#'
+#' # Checking out differences (netsim should have less)
+#' nlinks(net)
+#' nlinks(netsim)
+#'
+#' mapply(`-`, nlinks(net), nlinks(netsim))
+#'
+#' @export
+#' @rdname diffnetmatmult
+#' @family diffnet methods
+`%*%` <- function(x, y) UseMethod("%*%")
+
+#' @export
+#' @rdname diffnetmatmult
+`%*%.default` <- function(x, y) base::`%*%`(x=x,y=y)
+
+#' @export
+#' @rdname diffnetmatmult
+`%*%.diffnet` <- function(x, y) {
+
+  mat2dgCList <- function(w,z) {
+    w <- lapply(seq_len(nslices(z)), function(u) methods::as(w, "dgCMatrix"))
+    names(w) <- dimnames(z)[[3]]
+    w
+  }
+
+  if (inherits(x, "diffnet") && inherits(y, "diffnet")) {
+    x$graph <- mapply(base::`%*%`, x$graph, y$graph)
+  } else if (inherits(x, "diffnet") && !inherits(y, "diffnet")) {
+    if (identical(dim(x)[-3], dim(y)))
+      x$graph <- mapply(base::`%*%`, x$graph, mat2dgCList(y, x))
+    else stop("-y- must have the same dimmension as -x-")
+  } else if (inherits(y, "diffnet") && !inherits(x, "diffnet")) {
+    if (identical(dim(y)[-3], dim(x)))
+      x$graph <- mapply(base::`%*%`, mat2dgCList(x, y), y$graph)
+    else stop("-y- must have the same dimmension as -x-")
+  }
+
+  x
+}
 
 
 
@@ -1243,3 +1409,54 @@ nodes <- function(graph) {
   if (!inherits(graph, "diffnet")) stop("-graph- must be a 'diffnet' object")
   graph$meta$ids
 }
+
+#' @export
+#' @rdname as_diffnet
+#' @param FUN a function to be passed to lapply
+diffnetLapply <- function(graph, FUN, ...) {
+  lapply(seq_len(nslices(graph)), function(x, graph, ...) {
+    FUN(x,
+        graph               = graph$graph[[x]],
+        toa                 = graph$toa,
+        vertex.static.attrs = graph$vertex.static.attrs,
+        vertex.dyn.attrs    = graph$vertex.dyn.attrs[[x]],
+        adopt               = graph$adopt[,x,drop=FALSE],
+        cumadopt            = graph$cumadopt[,x,drop=FALSE],
+        meta                = graph$meta)
+    }, graph=graph,...)
+}
+# debug(diffnetLapply)
+# diffnetLapply(medInnovationsDiffNet, function(x, graph, cumadopt, ...) {
+#   sum(cumadopt)
+# })
+
+#' @export
+#' @rdname as_diffnet
+str.diffnet <- function(object, ...) {
+  utils::str(unclass(object))
+}
+
+#' @export
+#' @rdname as_diffnet
+dimnames.diffnet <- function(x) {
+  with(x, list(
+    meta$ids,
+    c(colnames(vertex.static.attrs), names(vertex.dyn.attrs[[1]])),
+    meta$pers)
+  )
+}
+
+#' @export
+#' @rdname as_diffnet
+#' @method t diffnet
+t.diffnet <- function(x) {
+  x$graph <- lapply(x$graph, getMethod("t", "dgCMatrix"))
+  x
+}
+
+#' @rdname as_diffnet
+#' @export
+dim.diffnet <- function(x) {
+  k <- length(with(x, c(colnames(vertex.static.attrs), names(vertex.dyn.attrs[[1]]))))
+  as.integer(with(x$meta, c(n, k, nper)))
+}
