@@ -5,11 +5,10 @@ using namespace Rcpp;
 // [[Rcpp::export]]
 double moran_cpp(const arma::colvec & x, const arma::sp_mat & w) {
   double xmean = mean(x);
-  int n = x.size();
 
   // Checking dims
   if (w.n_cols != w.n_rows) stop("-w- is not a square matrix");
-  if (n != w.n_cols) stop("-x- and -w- dimensions differ");
+  if (x.size() != w.n_cols) stop("-x- and -w- dimensions differ");
 
   // Weights sum
   double wsum = accu(w);
@@ -18,6 +17,6 @@ double moran_cpp(const arma::colvec & x, const arma::sp_mat & w) {
   double numer = accu((xcent * xcent.t()) % w);
   double denom = accu(pow(xcent, 2.0));
 
-  return (n/wsum)*(numer/(denom + 1e-15));
+  return (x.size()/wsum)*(numer/(denom + 1e-15));
 }
 
