@@ -7,11 +7,9 @@
 #define NETDIFFUSER_RGRAPH_WS_
 using namespace Rcpp;
 
-arma::umat sparse_indexes(const arma::sp_mat & mat);
+arma::sp_mat ring_lattice(int n, int k, bool undirected=true);
 
-arma::sp_mat ring_lattice(int n, int k);
-
-arma::sp_mat rewire_graph_cpp(
+arma::sp_mat rewire_endpoints(
     const arma::sp_mat & graph, double p,
     bool both_ends=false, bool self=false, bool multiple=false,
     bool undirected=false);
