@@ -9,9 +9,6 @@
 
 using namespace Rcpp;
 
-List struct_equiv_cpp(const arma::sp_mat & gdist,
-                      double v = 1.0,
-                      bool unscaled = false,
-                      bool inv = false, double invrep = 0.0);
+List struct_equiv_cpp(const arma::sp_mat & gdist, double v = 1.0);
 
 #endif
